@@ -172,6 +172,7 @@ class Models():
                                                tau_max=self.tau_max,
                                                mask_type=self.mask_type,
                                                cut_off=self.cut_off,
+                                               remove_overlaps=True,
                                                verbosity=self.verbosity)
 
             # Transform the data if needed
@@ -411,6 +412,7 @@ class Models():
                                                tau_max=self.tau_max,
                                                mask_type=self.mask_type,
                                                cut_off=cut_off,
+                                               remove_overlaps=True,
                                                verbosity=self.verbosity)
             # Get the dimensions out of the constructed array
             dim, T = array.shape
@@ -1220,18 +1222,28 @@ class Prediction(Models, PCMCI):
                  data_transform=None,
                  verbosity=0):
 
+        if dataframe.analysis_mode != 'single':
+            raise ValueError("Prediction class currently only supports single "
+                             "datasets.")
+
+        # dataframe.values = {0: dataframe.values[0]}
+
         # Default value for the mask
-        mask = dataframe.mask
-        if mask is None:
-            mask = np.zeros(dataframe.values.shape, dtype='bool')
+        if dataframe.mask is not None:
+            mask = dataframe.mask[0]
+        else:
+            mask = {0: np.zeros(dataframe.values[0].shape, dtype='bool')}
         # Get the dataframe shape
         T = len(dataframe.values)
         # Have the default dataframe be the training data frame
-        train_mask = np.copy(mask)
-        train_mask[[t for t in range(T) if t not in train_indices]] = True
-        self.dataframe = DataFrame(dataframe.values,
-                                   mask=train_mask,
-                                   missing_flag=dataframe.missing_flag)
+        train_mask = mask.copy()
+        train_mask[0][[t for t in range(T) if t not in train_indices]] = True
+        self.dataframe = dataframe
+        self.dataframe.mask = train_mask
+        self.dataframe._initialized_from = 'dict'
+                 # = DataFrame(dataframe.values[0],
+                 #                   mask=train_mask,
+                 #                   missing_flag=dataframe.missing_flag)
         # Initialize the models baseclass with the training dataframe
         Models.__init__(self,
                         dataframe=self.dataframe,
@@ -1241,8 +1253,8 @@ class Prediction(Models, PCMCI):
                         verbosity=verbosity)
 
         # Build the testing dataframe as well
-        self.test_mask = np.copy(mask)
-        self.test_mask[[t for t in range(T) if t not in test_indices]] = True
+        self.test_mask = mask.copy()
+        self.test_mask[0][[t for t in range(T) if t not in test_indices]] = True
 
         # Setup the PCMCI instance
         if cond_ind_test is not None:
@@ -1451,6 +1463,7 @@ class Prediction(Models, PCMCI):
                                                          mask=new_data_mask,
                                                          mask_type=self.mask_type,
                                                          cut_off=cut_off,
+                                                         remove_overlaps=True,
                                                          verbosity=self.verbosity)
             # Otherwise use the default values
             else:
@@ -1460,6 +1473,7 @@ class Prediction(Models, PCMCI):
                                                    mask=self.test_mask,
                                                    mask_type=self.mask_type,
                                                    cut_off=cut_off,
+                                                   remove_overlaps=True,
                                                    verbosity=self.verbosity)
             # Transform the data if needed
             a_transform = self.fitted_model[target]['data_transform']
